@@ -12,7 +12,7 @@ use File::Path;
 use File::Spec;
 use Data::Dumper;
 use Genezzo::GenDBI;
-use Genezzo::Contrib::Clustered::Clustered;
+use Genezzo::Contrib::Clustered;
 use Genezzo::Contrib::Clustered::GLock::GLock;
 use POSIX;
 
